![Build & Publish](https://github.com/josephbmanley/awsmedia-tool/workflows/Build%20&%20Publish/badge.svg) ![Version](https://img.shields.io/pypi/v/awsmedia-tool) ![Supported Versions](https://img.shields.io/pypi/pyversions/awsmedia-tool)

# awsmedia-tool

Simple AWS MediaStore tool

## Getting Started

### Installation

awsmedia-tool can easily be install using pip:

```bash
pip install awsmedia-tool
```
